==> foundation-utils-2.0.15.tgz: package/src/service/httpService.ts <==
import axios from 'axios';
// import { BaseConfig } from '@/config/storage'
// 线上环境配置axios.defaults.baseURL

//请求拦截器
axios.interceptors.request.use(
  config => {
    // 域名代理设置
    // if (new RegExp('^\/.*$').test(<string>config.url)) {
    //   config.baseURL = BaseConfig.apiBaseURL;
    // }
    config.headers['Access-Control-Allow-Credentials'] = true;
    config.headers['Access-Control-Allow-Origin'] = '*';
    return config;
  },
  error => {
    return Promise.reject(error);
  }
);

//响应拦截器即异常处理
axios.interceptors.response.use(
  response => {
    console.log('-------interceptors--response-----------', response);
    if (response.data.code === 0 || response.data.code === 200) {
      return Promise.resolve(response.data);
    } else {
      return Promise.reject(response.data.message || response.data.msg || response.data.errMsg);
    }
  },
  err => {
    console.log('-------interceptors--err-----------', err);
    return Promise.reject(err.response);
  }
);

class HttpService {
  /**
   * @description: 下载文件
   * @param {*}
   * @return {*}
   */
  downloadFile = (url: string) => {
    window.open(url);
  };


  //get请求
  get = (url: string, header?: any) => {
    return axios({
      method: 'get',
      url,
      headers: {
        ...(header || {}),
        'Content-Type': 'application/json;charse=UTF-8'
      },
    });
  }
  //post请求
  post = (url: string, param: any, header?: any) => {
    return axios({
      method: 'post',
      url,
      headers: {
        ...(header || {}),
        'Content-Type': 'application/json;charse=UTF-8'
      },
      data: param || {}
    });
  }
  //post请求
  put = (url: string, params?: any, header?: any) => {
    return axios({
      method: 'put',
      url,
      headers: {
        ...(header || {}),
        'Content-Type': 'application/json;charse=UTF-8'
      },
      data: params || {}
    });
  }
  // delete
  delete = (url: string, params?: any, header?: any) => {
    return axios({
      method: 'delete',
      url,
      headers: {
        ...(header || {})
      },
      params: params || {}
    });
  }
}

const httpService = () => {
  let service;
  if (!service) service = new HttpService();
  return service;
}

export { httpService };

==> foundation-utils-2.0.16.tgz: package/src/service/httpService.ts <==
import axios from 'axios';
// import { BaseConfig } from '@/config/storage'
// 线上环境配置axios.defaults.baseURL

//请求拦截器
axios.interceptors.request.use(
  config => {
    // 域名代理设置
    // if (new RegExp('^\/.*$').test(<string>config.url)) {
    //   config.baseURL = BaseConfig.apiBaseURL;
    // }
    config.headers['Access-Control-Allow-Credentials'] = true;
    config.headers['Access-Control-Allow-Origin'] = '*';
    return config;
  },
  error => {
    return Promise.reject(error);
  }
);

//响应拦截器即异常处理
axios.interceptors.response.use(
  response => {
    console.log('-------interceptors--response-----------', response);
    if (response.data.code === 0 || response.data.code === 200) {
      return Promise.resolve(response.data);
    } else {
      return Promise.reject(response.data.message || response.data.msg || response.data.errMsg);
    }
  },
  err => {
    console.log('-------interceptors--err-----------', err);
    return Promise.reject(err.response);
  }
);

class HttpService {
  /**
   * @description: 下载文件
   * @param {*}
   * @return {*}
   */
  downloadFile = (url: string) => {
    window.open(url);
  };


  //get请求
  get = (url: string, header?: any) => {
    return axios({
      method: 'get',
      url,
      headers: {
        ...(header || {}),
        'Content-Type': 'application/json;charse=UTF-8'
      },
    });
  }
  //post请求
  post = (url: string, param: any, header?: any) => {
    return axios({
      method: 'post',
      url,
      headers: {
        ...(header || {}),
        'Content-Type': 'application/json;charse=UTF-8'
      },
      data: param || {}
    });
  }
  //post请求
  put = (url: string, params?: any, header?: any) => {
    return axios({
      method: 'put',
      url,
      headers: {
        ...(header || {}),
        'Content-Type': 'application/json;charse=UTF-8'
      },
      data: params || {}
    });
  }
  // delete
  delete = (url: string, params?: any, header?: any) => {
    return axios({
      method: 'delete',
      url,
      headers: {
        ...(header || {})
      },
      params: params || {}
    });
  }
}

const httpService = (): HttpService => {
  let service;
  if (!service) service = new HttpService();
  return service;
}

export { httpService };
